@@ -82,14 +82,14 @@ def pFBA(model, objective=None, obj_frac=None, minimize=False, constraints=None,
         for r_id in reactions:
             if model.reactions[r_id].reversible:
                 pos, neg = r_id + '_p', r_id + '_n'
-                solver.add_variable(pos, 0, inf, update=False)
-                solver.add_variable(neg, 0, inf,  update=False)
+                solver.add_variable(pos, 0, inf)
+                solver.add_variable(neg, 0, inf)
         solver.update()
         for r_id in reactions:
             if model.reactions[r_id].reversible:
                 pos, neg = r_id + '_p', r_id + '_n'
-                solver.add_constraint('c' + pos, {r_id: -1, pos: 1}, '>', 0, update=False)
-                solver.add_constraint('c' + neg, {r_id: 1, neg: 1}, '>', 0, update=False)
+                solver.add_constraint('c' + pos, {r_id: -1, pos: 1}, '>', 0)
+                solver.add_constraint('c' + neg, {r_id: 1, neg: 1}, '>', 0)
         solver.update()
 
     objective = dict()
@@ -102,7 +102,6 @@ def pFBA(model, objective=None, obj_frac=None, minimize=False, constraints=None,
             objective[r_id] = 1
 
     solution = solver.solve(objective, minimize=True, constraints=constraints)
-    solver.remove_constraint('obj')
     solution.pre_solution = pre_solution
 
     if cleanup:
@@ -195,8 +194,8 @@ def CAFBA(model, objective=None, minimize=False, wc=0, we=8.3e-4, wr=0.169, pmax
             if carbon_source in model.reactions[r_id].stoichiometry:
                 if model.reactions[r_id].reversible:
                     pos, neg = r_id + '+', r_id + '-'
-                    solver.add_variable(pos, 0, inf, update=False)
-                    solver.add_variable(neg, 0, inf, update=False)
+                    solver.add_variable(pos, 0, inf)
+                    solver.add_variable(neg, 0, inf)
                     uptake.append(r_id + '+')
                     uptake.append(r_id + '-')
                     splits[r_id] = pos, neg
@@ -206,8 +205,8 @@ def CAFBA(model, objective=None, minimize=False, wc=0, we=8.3e-4, wr=0.169, pmax
         for r_id in model.get_reactions_by_type(ReactionType.ENZYMATIC):
             if model.reactions[r_id].reversible:
                 pos, neg = r_id + '+', r_id + '-'
-                solver.add_variable(pos, 0, inf, update=False)
-                solver.add_variable(neg, 0, inf, update=False)
+                solver.add_variable(pos, 0, inf)
+                solver.add_variable(neg, 0, inf)
                 enzymatic.append(r_id + '+')
                 enzymatic.append(r_id + '-')
                 splits[r_id] = pos, neg
@@ -217,8 +216,8 @@ def CAFBA(model, objective=None, minimize=False, wc=0, we=8.3e-4, wr=0.169, pmax
         solver.update()
 
         for r_id, (pos, neg) in splits.items():
-            solver.add_constraint('c' + pos, {r_id: -1, pos: 1}, '>', 0, update=False)
-            solver.add_constraint('c' + neg, {r_id: 1, neg: 1}, '>', 0, update=False)
+            solver.add_constraint('c' + pos, {r_id: -1, pos: 1}, '>', 0)
+            solver.add_constraint('c' + neg, {r_id: 1, neg: 1}, '>', 0)
         solver.update()
 
     main_constr = {}
@@ -228,12 +227,10 @@ def CAFBA(model, objective=None, minimize=False, wc=0, we=8.3e-4, wr=0.169, pmax
         main_constr[r_id] = wc
     main_constr[model.biomass_reaction] = wr
 
-    solver.add_constraint('alloc', main_constr, '=', pmax, update=True)
+    solver.add_constraint('alloc', main_constr, '=', pmax)
 
     solution = solver.solve(objective, minimize=minimize, constraints=constraints)
 
-    solver.remove_constraint('alloc')
-
     if cleanup:
         for (pos, neg) in splits.values():
             del solution.values[pos]
@@ -242,42 +239,6 @@ def CAFBA(model, objective=None, minimize=False, wc=0, we=8.3e-4, wr=0.169, pmax
     return solution
 
 
-def MOMA(model, reference=None, constraints=None, reactions=None, solver=None):
-    """ Run a Minimization Of Metabolic Adjustment (MOMA) simulation:
-
-    Arguments:
-        model (CBModel): a constraint-based model
-        reference (dict): reference flux distribution (optional)
-        constraints (dict): environmental or additional constraints (optional)
-        reactions (list): list of reactions to include in the objective (optional, default: all)
-        solver (Solver): solver instance instantiated with the model, for speed (optional)
-
-    Returns:
-        Solution: solution
-    """
-
-    if reference is None:
-        wt_solution = pFBA(model)
-        reference = wt_solution.values
-    else:
-        reactions = reference.keys()
-
-    if reactions is None:
-        reactions = model.reactions.keys()
-
-    quad_obj = {(r_id, r_id): 1 for r_id in reactions}
-    lin_obj = {r_id: -2 * reference[r_id] for r_id in reactions}
-
-    if not solver:
-        solver = solver_instance(model)
-
-    solution = solver.solve(lin_obj, quadratic=quad_obj, minimize=True, constraints=constraints)
-
-    solution.reference = reference
-
-    return solution
-
-
 def lMOMA(model, reference=None, constraints=None, reactions=None, solver=None):
     """ Run a (linear version of) Minimization Of Metabolic Adjustment (lMOMA) simulation:
 
@@ -308,13 +269,13 @@ def lMOMA(model, reference=None, constraints=None, reactions=None, solver=None):
         solver.lMOMA_flag = True
         for r_id in reactions:
             d_pos, d_neg = r_id + '_d+', r_id + '_d-'
-            solver.add_variable(d_pos, 0, inf, update=False)
-            solver.add_variable(d_neg, 0, inf, update=False)
+            solver.add_variable(d_pos, 0, inf)
+            solver.add_variable(d_neg, 0, inf)
         solver.update()
         for r_id in reactions:
             d_pos, d_neg = r_id + '_d+', r_id + '_d-'
-            solver.add_constraint('c' + d_pos, {r_id: -1, d_pos: 1}, '>', -reference[r_id], update=False)
-            solver.add_constraint('c' + d_neg, {r_id: 1, d_neg: 1}, '>', reference[r_id], update=False)
+            solver.add_constraint('c' + d_pos, {r_id: -1, d_pos: 1}, '>', -reference[r_id])
+            solver.add_constraint('c' + d_neg, {r_id: 1, d_neg: 1}, '>', reference[r_id])
         solver.update()
 
     objective = dict()
@@ -354,15 +315,16 @@ def ROOM(model, reference=None, constraints=None, wt_constraints=None, reactions
     U = 1e6
     L = -1e6
 
-    if not solver:
-        solver = solver_instance(model)
 
     if reference is None:
-        wt_solution = pFBA(model, constraints=wt_constraints, solver=solver)
+        wt_solution = pFBA(model, constraints=wt_constraints)
         reference = wt_solution.values
 
     if reactions is None:
         reactions = reference.keys()
+    
+    if not solver:
+        solver = solver_instance(model)
 
     objective = dict()
     if not hasattr(solver, 'ROOM_flag'):
@@ -370,7 +332,7 @@ def ROOM(model, reference=None, constraints=None, wt_constraints=None, reactions
 
         for r_id in reactions:
             y_i = 'y_' + r_id
-            solver.add_variable(y_i, 0, 1, vartype=VarType.BINARY, update=False)
+            solver.add_variable(y_i, 0, 1, vartype=VarType.BINARY)
             objective[y_i] = 1
         solver.update()
 
@@ -384,8 +346,8 @@ def ROOM(model, reference=None, constraints=None, wt_constraints=None, reactions
                 w_i_max = reference[r_id]
             w_u = w_i_max + delta * abs(w_i_max) + epsilon
             w_l = w_i_min - delta * abs(w_i_min) - epsilon
-            solver.add_constraint('c' + r_id + '_u', {r_id: 1, y_i: (w_u - U)}, '<', w_u, update=False)
-            solver.add_constraint('c' + r_id + '_l', {r_id: 1, y_i: (w_l - L)}, '>', w_l, update=False)
+            solver.add_constraint('c' + r_id + '_u', {r_id: 1, y_i: (w_u - U)}, '<', w_u)
+            solver.add_constraint('c' + r_id + '_l', {r_id: 1, y_i: (w_l - L)}, '>', w_l)
         solver.update()
 
     if solutions == 1:
