@@ -50,6 +50,10 @@ class ExchangeDetection(Enum):
 DEFAULT_SBML_LEVEL = 3
 DEFAULT_SBML_VERSION = 1
 
+IDENTIFIERS_PATTERN = re.compile(r'/([^/]+)/([^/]+)$')
+URL_IDENTIFIERS_PREFIX = "https://identifiers.org"
+
+
 non_alphanum = re.compile(r'\W+')
 re_type = type(non_alphanum)
 
@@ -391,6 +395,11 @@ def sanitize_id(identifier):
 def parse_gpr_rule(rule, prefix=None):
     if not rule:
         return None
+    
+    if isinstance(rule, list):
+        if len(rule) != 1:
+            raise RuntimeWarning(f'Unexpected number of items in GPR:{rule}')
+        rule = rule[0]
 
     rule = rule.replace('(', '( ').replace(')', ' )')
 
@@ -539,9 +548,38 @@ def extract_metadata(sbml_elem, elem):
     if notes:
         recursive_node_parser(notes, elem.metadata)
 
-    annotation = sbml_elem.getAnnotationString()
-    if annotation:
-        elem.metadata['XMLAnnotation'] = annotation
+    parse_annotations(sbml_elem, elem)
+
+def parse_annotations(sbml_elem, elem):
+    """
+    Parse the annotations found in XML Annotations like
+    http://identifiers.org/reactome/R-ALL-419151
+
+    There is a question whether all annotations should be added as lists, or 
+    only in those cases where you have multiple annotations from the same db, 
+    and then keep the rest as strings. Now, all annotations gets added as lists.
+
+    """
+    for term in sbml_elem.getCVTerms():
+        n_resources = term.getNumResources()
+        for i  in range(n_resources):
+            match = IDENTIFIERS_PATTERN.search(term.getResourceURI(i))
+            if match:
+                db = match.group(1)
+                db_id = match.group(2)
+
+                try:
+                    elem.metadata[db]
+                except KeyError:
+                    elem.metadata[db] = [db_id]
+                else:
+                    elem.metadata[db].append(db_id)
+
+            else:
+                warn(f'Could not extract annotation from {term.getResourceURI(i)}')
+
+
+
 
 
 def recursive_node_parser(node, cache):
@@ -617,6 +655,8 @@ def save_metabolites(model, sbml_model, flavor=None):
         species.setName(metabolite.name)
         species.setCompartment(metabolite.compartment)
         species.setHasOnlySubstanceUnits(True)
+        species.setConstant(False)
+        species.setBoundaryCondition(model.compartments[metabolite.compartment].external)
 
         if flavor in {Flavor.BIGG.value, Flavor.FBC2.value}:
             fbc_species = species.getPlugin('fbc')
@@ -795,23 +835,38 @@ def save_fbc_gprs(model, sbml_model):
 
 
 def save_metadata(elem, sbml_elem):
-    sbml_elem.setMetaId(elem.id)
-
+    meta_id = f"meta_{sbml_elem.getId()}"
+    sbml_elem.setMetaId(meta_id)
+    note_keys = ['CHARGE', 'FORMULA']
+    notes_dict = {}
+    
     if elem.metadata:
-        try:
-            if 'XMLAnnotation' in elem.metadata:
-                sbml_elem.setAnnotation(elem.metadata['XMLAnnotation'])
+        for key, annotations in elem.metadata.items():
+            if key == 'SBOTerm':
+                sbml_elem.setSBOTerm(annotations)
+            elif key in note_keys:
+                notes_dict[key] = annotations
+            elif key == 'XMLAnnotation':
+                continue
+            else:
+                # Assume this is an annotation
+                if not isinstance(annotations, list):
+                    annotations = [annotations]
+                for annotation in annotations:
+                    if annotation:
+                        cv = sb.CVTerm()
+                        cv.setQualifierType(sb.BIOLOGICAL_QUALIFIER)
+                        cv.setBiologicalQualifierType(sb.BQB_IS)
+                        annotation_string = f"{URL_IDENTIFIERS_PREFIX}/{key}/{annotation}"
+                        cv.addResource(annotation_string)
+                        sbml_elem.addCVTerm(cv)
 
-            if 'SBOTerm' in elem.metadata:
-                sbml_elem.setSBOTerm(elem.metadata['SBOTerm'])
+    if len(notes_dict):
+        notes = [f'<p>{key}: {escape(value)}</p>'
+                 for key, value in notes_dict.items()
+                 if key != 'XMLAnnotation']
+        note_string = '<html>' + ''.join(notes) + '</html>'
+        note_xml = sb.XMLNode.convertStringToXMLNode(note_string)
+        note_xml.getNamespaces().add('http://www.w3.org/1999/xhtml')
+        sbml_elem.setNotes(note_xml)
 
-            notes = [f'<p>{key}: {escape(value)}</p>'
-                     for key, value in elem.metadata.items()
-                     if key != 'XMLAnnotation']
-            note_string = '<html>' + ''.join(notes) + '</html>'
-            note_xml = sb.XMLNode.convertStringToXMLNode(note_string)
-            note_xml.getNamespaces().add('http://www.w3.org/1999/xhtml')
-            sbml_elem.setNotes(note_xml)
-
-        except AttributeError:
-            warn(f"Unable to save metadata for object {sbml_elem.getId()}")
